<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=<%= charset %>" />
    <title><%= @title %></title>
    <%= erb(:headers) %>
  </head>
  <body>
    <div id="content">
      <h1><%= @title %></h1>
      <%= yieldall %>
    </div>

    <%= erb(:footer) %>
  </body>
</html>