<script>
$(document.getElementById("<%= anchor_for(object) %>")).prepend(
  '<a class="permalink" href="/<%= base_path(router.docs_prefix) %>/<%= urlencode serializer.serialized_path(object) %>">permalink</a>');
</script>
